<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// T
	'texte_type_urls' => 'Gallout a rit dibab amañ dindan an doare ma vo jedet chomlec’h ar pajennoù.',
	'texte_type_urls_attention' => 'Diwallit, ne’z aio an dra-mañ en-dro nemet ma vez staliet mat ar restr @htaccess@ e gwrizienn al lec’hienn.',
	'titre_type_urls' => 'Seurt chomlec’hioù URL'
);

?>
